class ETFConverter:
    """Main index price convert into ETF price"""

    _default_precision = 2

    def __init__(self, index_price: float, etf: float) -> None:
        self.index_price = index_price
        self.etf = etf

    @property
    def etf_precision(self) -> int:
        return len(str(self.etf).split(".")[1]) if "." in str(self.etf) else self._default_precision

    def tgt_etf_price(self, tgt_index_price: float) -> float:
        return round(self.etf * tgt_index_price / self.index_price, self.etf_precision)



import pytest

from tradex.utils.etf import ETFConverter


@pytest.mark.parametrize(
    ("index_price", "etf_price", "tgt_index_price", "expected"),
    [
        (683.397, 0.78, 1021.3213, 1.17),
        (683.397, 0.782, 1135, 1.299),
        (683.397, 1, 1700, 2.49),
    ],
)
def test_tgt_etf_price(index_price, etf_price, tgt_index_price, expected):
    converter = ETFConverter(index_price=index_price, etf=etf_price)
    tgt_etf_price = converter.tgt_etf_price(tgt_index_price)
    assert tgt_etf_price == expected
